@@ -3,7 +3,7 @@
 """
 Workspace Overview
 Author: Jacob Vlijm
-Copyright © 2017-2019 Ubuntu Budgie Developers
+Copyright © 2017-2020 Ubuntu Budgie Developers
 Website: https://ubuntubudgie.org
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free Software
@@ -34,7 +34,9 @@ class WsOverviewWin(GObject.Object):
     def __init__(self):
 
         GObject.Object.__init__(self)
-        settings = Gio.Settings.new("org.ubuntubudgie.plugins.budgie-extras")
+        settings = Gio.Settings.new(
+            "org.ubuntubudgie.plugins.budgie-wsoverview"
+        )
         settings.bind("ws-overview-index", self,
                       'mode_index',
                       Gio.SettingsBindFlags.DEFAULT)
@@ -86,9 +88,9 @@ class WsOverviewWin(GObject.Object):
             if m[1]:
                 # flattened submenu
                 self.submenu = Gtk.Menu()
-                for l in [d for d in m[1]]:
-                    app = l[0]
-                    wins = [[it[0], it[1]] for it in l[1]]
+                for sl in [d for d in m[1]]:
+                    app = sl[0]
+                    wins = [[it[0], it[1]] for it in sl[1]]
                     for w in wins:
                         name = self.shortname(w[0]) + "  -  " + app
                         winmention = Gtk.MenuItem(name)
