@@ -15,17 +15,21 @@ touch budgie-extras.po
 
 for file in `find . -name "*.py" -or -name "*.vala"`; do
     if [[ `grep -F "_(\"" $file` ]]; then
-        do_gettext $file --add-comments
+        grep -q "$file" POTFILES.skip
+        if [[ $? != 0 ]]; then
+            echo $file
+            do_gettext $file --add-comments
+        fi
     fi
 done
 
-#for file in `find src -name "*.ui"`; do
-#    if [[ `grep -F "translatable=\"yes\"" $file` ]]; then
-#        do_intltool gettext/glade $file
-#        do_gettext ${file}.h --add-comments --keyword=N_:1
-#        rm $file.h
-#    fi
-#done
+for file in `find . -name "*.ui"`; do
+    if [[ `grep -F "translatable=\"yes\"" $file` ]]; then
+        do_intltool gettext/glade $file
+        do_gettext ${file}.h --add-comments --keyword=N_:1
+        rm $file.h
+    fi
+done
 
 for file in `find . -name "*.in"`; do
     if [[ `grep -E "^_*" $file` ]]; then
